# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.create_split_options_request

class CancelSplitRequest(object):

    """Implementation of the 'CancelSplitRequest' model.

    Split

    Attributes:
        mtype (string): Split type
        amount (int): Amount
        recipient_id (string): Recipient id
        options (CreateSplitOptionsRequest): The split options request
        split_rule_id (string): Rule id

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "amount":'amount',
        "recipient_id":'recipient_id',
        "options":'options',
        "split_rule_id":'split_rule_id'
    }

    def __init__(self,
                 mtype=None,
                 amount=None,
                 recipient_id=None,
                 options=None,
                 split_rule_id=None):
        """Constructor for the CancelSplitRequest class"""

        # Initialize members of the class
        self.mtype = mtype
        self.amount = amount
        self.recipient_id = recipient_id
        self.options = options
        self.split_rule_id = split_rule_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        amount = dictionary.get('amount')
        recipient_id = dictionary.get('recipient_id')
        options = pagarmecoreapi.models.create_split_options_request.CreateSplitOptionsRequest.from_dictionary(dictionary.get('options')) if dictionary.get('options') else None
        split_rule_id = dictionary.get('split_rule_id')

        # Return an object of this model
        return cls(mtype,
                   amount,
                   recipient_id,
                   options,
                   split_rule_id)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import pagarmecoreapi.models.get_pix_bank_account_response

class GetPixPayerResponse(object):

    """Implementation of the 'GetPixPayerResponse' model.

    Pix payer data.

    Attributes:
        name (string): TODO: type description here.
        document (string): TODO: type description here.
        document_type (string): TODO: type description here.
        bank_account (GetPixBankAccountResponse): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "document":'document',
        "document_type":'document_type',
        "bank_account":'bank_account'
    }

    def __init__(self,
                 name=None,
                 document=None,
                 document_type=None,
                 bank_account=None):
        """Constructor for the GetPixPayerResponse class"""

        # Initialize members of the class
        self.name = name
        self.document = document
        self.document_type = document_type
        self.bank_account = bank_account


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        document = dictionary.get('document')
        document_type = dictionary.get('document_type')
        bank_account = pagarmecoreapi.models.get_pix_bank_account_response.GetPixBankAccountResponse.from_dictionary(dictionary.get('bank_account')) if dictionary.get('bank_account') else None

        # Return an object of this model
        return cls(name,
                   document,
                   document_type,
                   bank_account)





# -*- coding: utf-8 -*-

"""
    pagarmecoreapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GetPixBankAccountResponse(object):

    """Implementation of the 'GetPixBankAccountResponse' model.

    Payer's bank details.

    Attributes:
        bank_name (string): TODO: type description here.
        ispb (string): TODO: type description here.
        branch_code (string): TODO: type description here.
        account_number (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "bank_name":'bank_name',
        "ispb":'ispb',
        "branch_code":'branch_code',
        "account_number":'account_number'
    }

    def __init__(self,
                 bank_name=None,
                 ispb=None,
                 branch_code=None,
                 account_number=None):
        """Constructor for the GetPixBankAccountResponse class"""

        # Initialize members of the class
        self.bank_name = bank_name
        self.ispb = ispb
        self.branch_code = branch_code
        self.account_number = account_number


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        bank_name = dictionary.get('bank_name')
        ispb = dictionary.get('ispb')
        branch_code = dictionary.get('branch_code')
        account_number = dictionary.get('account_number')

        # Return an object of this model
        return cls(bank_name,
                   ispb,
                   branch_code,
                   account_number)


